==> tdm_3.0.0.tar.gz: tdm/R/all.Evesm.R <==
all.Evesm<-function(){
     cat("\n")
     note_for_Evesm_input()
     cat("\n")
     note_for_close_window()
     ### EveSMMpar<-data.frame(parameter=c("bw (kg)","age (yr)","race","Ery","D (mg)","tau (hr)"),value=c(0))
     EveSMMpar<-data.frame(parameter=c("bw (kg)","age (yr)","race","Ery","D (mg)","tau (hr)"),value=c(78,56,0,0,1.5,24))
     ### EveSMMpar<-edit(EveSMMpar)
     cat("\n Input data are as follows:\n")
     cat(" --------------------------\n")
     show(EveSMMpar);cat("\n\n")
##     EveSMMpar<-ycheck(EveSMMpar)
     note_for_Evesm_conc_input()
     cat("\n")
     note_for_close_window()
     EveSMpar<-data.frame(ts=c(12, 20),conc=c(12.1,7.4))
     ### EveSMpar<-edit(EveSMpar)
     cat("\n Input conc. are as follows:\n")
     cat(" --------------------------\n")
     show(EveSMpar);cat("\n\n")
##     EveSMpar<-mscheck(EveSMpar)
     cat("\n")
     Eve.sm(length(EveSMpar$ts),EveSMpar$conc,EveSMpar$ts,EveSMMpar[6,2],EveSMMpar[5,2],EveSMMpar[1,2],EveSMMpar[2,2],EveSMMpar[3,2],EveSMMpar[4,2])
     note_for_convergence_plots()
     ### convergence_plots_sep()
     note_for_Evesm_output()
     ### show(samplesStats("*"))
     ### show obs. and calc. conc. here  -YJ
     cat("\n\n")
     for(i in 1:length(EveSMpar$ts)){
         Cx<-Evecpr(6.07,EveSMMpar[5,2],EveSMMpar[6,2],EveSMpar$ts[i])
         coutput<-data.frame(conc=c("obs. conc.","calc. conc."), values=c(EveSMpar$conc[i],Cx))
         cat("--- Everolimus blood conc. (mcg/L) at Time =",EveSMpar$ts[i],"---\n")
         show(coutput);cat("\n")
     }
     cat("\n") 
     C<-Evecpr(6.07,EveSMMpar[5,2],EveSMMpar[6,2],EveSMMpar[6,2])
     ### sim<-matrix(C[1 ,1])
     coutput<-data.frame(C)
     colnames(coutput)<-list("Ctss_pr (mcg/L)")
     show(coutput)    
     cat("\n") 
     Eve.more()
}

==> tdm_3.0.3.tar.gz: tdm/R/all.Evesm.R <==
all.Evesm<-function(){
     cat("\n")
     note_for_Evesm_input()
     cat("\n")
     note_for_close_window()
     ### EveSMMpar<-data.frame(parameter=c("bw (kg)","age (yr)","race","Ery","D (mg)","tau (hr)"),value=c(0))
     EveSMMpar<-data.frame(parameter=c("bw (kg)","age (yr)","race","Ery","D (mg)","tau (hr)"),value=c(78,56,0,0,1.5,24))
     EveSMMpar<-edit(EveSMMpar)
     cat("\n Input data are as follows:\n")
     cat(" --------------------------\n")
     show(EveSMMpar);cat("\n\n")
##     EveSMMpar<-ycheck(EveSMMpar)
     note_for_Evesm_conc_input()
     cat("\n")
     note_for_close_window()
     EveSMpar<-data.frame(ts=c(12, 20),conc=c(12.1,7.4))
     ### EveSMpar<-edit(EveSMpar)
     cat("\n Input conc. are as follows:\n")
     cat(" --------------------------\n")
     show(EveSMpar);cat("\n\n")
##     EveSMpar<-mscheck(EveSMpar)
     cat("\n")
     Eve.sm(length(EveSMpar$ts),EveSMpar$conc,EveSMpar$ts,EveSMMpar[6,2],EveSMMpar[5,2],EveSMMpar[1,2],EveSMMpar[2,2],EveSMMpar[3,2],EveSMMpar[4,2])
     note_for_convergence_plots()
     ### convergence_plots_sep()
     note_for_Evesm_output()
     ### show(samplesStats("*"))
     ### show obs. and calc. conc. here  -YJ
     cat("\n\n")
     for(i in 1:length(EveSMpar$ts)){
         Cx<-Evecpr(6.07,EveSMMpar[5,2],EveSMMpar[6,2],EveSMpar$ts[i])
         coutput<-data.frame(conc=c("obs. conc.","calc. conc."), values=c(EveSMpar$conc[i],Cx))
         cat("--- Everolimus blood conc. (mcg/L) at Time =",EveSMpar$ts[i],"---\n")
         show(coutput);cat("\n")
     }
     cat("\n") 
     C<-Evecpr(6.07,EveSMMpar[5,2],EveSMMpar[6,2],EveSMMpar[6,2])
     ### sim<-matrix(C[1 ,1])
     coutput<-data.frame(C)
     colnames(coutput)<-list("Ctss_pr (mcg/L)")
     show(coutput)    
     cat("\n") 
     Eve.more()
}
